summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/webui/ntp/suggestions_combiner.h
diff options
context:
space:
mode:
authormacourteau@chromium.org <macourteau@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-14 22:25:02 +0000
committermacourteau@chromium.org <macourteau@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-14 22:25:02 +0000
commite4196de4c47bdbf700f6d0e0fb0218cdb98e489e (patch)
treec7e1e9ca619525680bd2c5e46bf71d4f841ec163 /chrome/browser/ui/webui/ntp/suggestions_combiner.h
parentda1cae582888c81287e2e6d898bf01e372cb323b (diff)
downloadchromium_src-e4196de4c47bdbf700f6d0e0fb0218cdb98e489e.zip
chromium_src-e4196de4c47bdbf700f6d0e0fb0218cdb98e489e.tar.gz
chromium_src-e4196de4c47bdbf700f6d0e0fb0218cdb98e489e.tar.bz2
Adds basic information about suggestions to the chrome://suggestions-internals/ page.
BUG=none TEST=Load the chrome://suggestions-internals/ page in Chrome, and make sure that there is a table shown with some data. Review URL: https://chromiumcodereview.appspot.com/10389100 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@136993 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/webui/ntp/suggestions_combiner.h')
-rw-r--r--chrome/browser/ui/webui/ntp/suggestions_combiner.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/chrome/browser/ui/webui/ntp/suggestions_combiner.h b/chrome/browser/ui/webui/ntp/suggestions_combiner.h
index 65253f3..5548efa 100644
--- a/chrome/browser/ui/webui/ntp/suggestions_combiner.h
+++ b/chrome/browser/ui/webui/ntp/suggestions_combiner.h
@@ -43,18 +43,20 @@ class SuggestionsCombiner {
// Fetch a new set of items from the various suggestion sources.
void FetchItems(Profile* profile);
- base::ListValue* GetPagesValue();
+ base::ListValue* GetPageValues();
// Called by a source when its items are ready. Make sure suggestion sources
// call this method exactly once for each call to
// SuggestionsSource::FetchItems.
void OnItemsReady();
+ void SetSuggestionsCount(size_t suggestions_count);
+
private:
// Fill the pages value from the suggestion sources so they can be sent to
// the javascript side. This should only be called when all the suggestion
// sources have items ready.
- void FillPagesValue();
+ void FillPageValues();
typedef ScopedVector<SuggestionsSource> SuggestionsSources;
@@ -74,7 +76,7 @@ class SuggestionsCombiner {
size_t suggestions_count_;
// Informations to send to the javascript side.
- scoped_ptr<base::ListValue> pages_value_;
+ scoped_ptr<base::ListValue> page_values_;
DISALLOW_COPY_AND_ASSIGN(SuggestionsCombiner);
};
@@ -43,18 +43,20 @@ class SuggestionsCombiner {
private:
- // Fill the pages value from the suggestion sources so they can be sent to
- // the javascript side. This should only be called when all the suggestion
+ // Fill the page values from the suggestion sources so they can be sent to
+ // the JavaScript side. This should only be called when all the suggestion
// sources have items ready.